Module collections

Module collections 

Hash map and set types with the environment’s default hasher.

Modules

hash_map
A hash map implemented with quadratic probing and SIMD lookup.
hash_set
A hash set implemented as a HashMap where the value is ().

Structs

DefaultHashBuilder
The default hasher used by the environment’s hash collections. Default hash builder for the S type parameter of HashMap and HashSet.

Type Aliases

HashMap
A hash map with the environment’s default hasher, usable in every environment (std, no-std and wasm).
HashSet
A hash set with the environment’s default hasher, usable in every environment (std, no-std and wasm).