store

Function store 

pub fn store<K: StoreKey, V: StoreValue>(options: StoreOptions) -> Store<K, V>
A Store created from the options, bound to the active environment whenever the options name a storage.

let store: Store<Key, Value> = cubecl_environment::environment::store(
    StoreOptions::new()
        .storage(Namespace::new("cuda/ptx"))
        .cache(CacheOption::Lazy),
);