Read async data without having to decorate each function with async notation.
Functions
- read_
sync - Read a future synchronously.
- try_
read_ sync - Read a future synchronously.
Read async data without having to decorate each function with async notation.