CacheOption

Enum CacheOption 

pub enum CacheOption {
    Eager,
    Lazy,
}
How a Store populates its in-memory map from its storage.

Variants



Eager

Scan everything at open. Reads are complete: a miss is a miss and never queries the storage.



Lazy

Fault entries in from the storage on first access. Right when the values are large enough that loading all of them eagerly is wasteful, typically compilation artifacts.